==> gephex-0.4.3b.tar.bz2: gephex-0.4.3/engine/src/renderer/typefactory.h <==
/* This source file is a part of the GePhex Project.

 Copyright (C) 2001-2004

 Georg Seidel <georg@gephex.org> 
 Martin Bayer <martin@gephex.org> 
 Phillip Promesberger <coma@gephex.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.*/

#ifndef INCLUDED_TYPEFACTORY_H
#define INCLUDED_TYPEFACTORY_H

#include <list>
#include <map>

#include "interfaces/itypefactory.h"
#include "utils/autoptr.h"

class IType;
class ITypeClass;

namespace renderer
{

class TypeRegistry
{
public:
  virtual void registerTypeClass(int id,const ITypeClass& typeClass) = 0;
};

class TypeFactory : public ITypeFactory, public TypeRegistry
{
public:
  TypeFactory();
  virtual ~TypeFactory();
  virtual IType* buildNew(int id) const;
  
  virtual void registerTypeClass(int id, const ITypeClass& typeClass);

private:
  typedef std::map<int, utils::AutoPtr<ITypeClass> > ClassMap;
  ClassMap typeClasses;
};

} //end of namespace

#endif

==> gephex-0.4.4.tar.bz2: gephex-0.4.4/engine/src/renderer/typefactory.h <==
/* This source file is a part of the GePhex Project.

 Copyright (C) 2001-2004

 Georg Seidel <georg@gephex.org> 
 Martin Bayer <martin@gephex.org> 
 Phillip Promesberger <coma@gephex.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.*/

#ifndef INCLUDED_TYPEFACTORY_H
#define INCLUDED_TYPEFACTORY_H

#include <list>
#include <map>

#include "interfaces/itypefactory.h"
#include "utils/autoptr.h"

class IType;
class ITypeClass;

namespace renderer
{

class TypeRegistry
{
public:
  virtual void registerTypeClass(int id,const ITypeClass& typeClass) = 0;
};

class TypeFactory : public ITypeFactory, public TypeRegistry
{
public:
  TypeFactory();
  virtual ~TypeFactory();
  virtual IType* buildNew(int id) const;
  
  virtual void registerTypeClass(int id, const ITypeClass& typeClass);

private:
  typedef std::map<int, const ITypeClass* > ClassMap;
  ClassMap typeClasses;
};

} //end of namespace

#endif
